*******************************
*Introduction to SPSS
*September 4/5, 2013
*StatLab@UVa Library
*Michele Claibourn
*******************************

*Reading an SPSS dataset in.
GET FILE='C:\Users\jcf2d\Documents\workshops\SPSS\collegeCompletion.sav'.

*Reading a .csv or .txt file in.
*Code pasted from "File -- Read Text Data" GUI. 
GET DATA 
  /TYPE=TXT 
  /FILE="C:\Users\jcf2d\Documents\workshops\SPSS\collegeCompletion.txt" 
  /DELCASE=LINE 
  /DELIMITERS="\t" 
  /ARRANGEMENT=DELIMITED 
  /FIRSTCASE=2 
  /IMPORTCASE=ALL 
  /VARIABLES= 
  unitid F6.0 
  chronname A58 
  city A17 
  state A20 
  level A6 
  control A22 
  basic A76 
  hbcu A1 
  flagship A1 
  long_x F11.6 
  lat_y F9.6 
  site A90 
  student_count F5.0 
  awards_per_value F5.1 
  awards_per_state_value F4.1 
  awards_per_natl_value F4.1 
  exp_award_value F6.0 
  exp_award_state_value F6.0 
  exp_award_natl_value F5.0 
  ft_pct F4.1 
  fte_value F5.0 
  med_sat_value F4.0 
  med_sat_percentile F2.0 
  aid_value F5.0 
  aid_percentile F3.0 
  endow_value F7.0 
  endow_percentile F2.0 
  grad_100_value F4.1 
  grad_100_percentile F2.0 
  grad_150_value F4.1 
  grad_150_percentile F2.0 
  pell_value F4.1 
  pell_percentile F2.0 
  retain_value F4.1 
  retain_percentile F2.0 
  ft_fac_value F4.1 
  ft_fac_percentile F2.0 
  vsa_year F4.0 
  vsa_grad_after4_first F4.1 
  vsa_grad_elsewhere_after4_first F3.1 
  vsa_enroll_after4_first F4.1 
  vsa_enroll_elsewhere_after4_first F4.1 
  vsa_grad_after6_first F4.1 
  vsa_grad_elsewhere_after6_first F4.1 
  vsa_enroll_after6_first F4.1 
  vsa_enroll_elsewhere_after6_first F4.1 
  vsa_grad_after4_transfer F4.1 
  vsa_grad_elsewhere_after4_transfer F3.1 
  vsa_enroll_after4_transfer F4.1 
  vsa_enroll_elsewhere_after4_transfer F4.1 
  vsa_grad_after6_transfer F4.1 
  vsa_grad_elsewhere_after6_transfer F4.1 
  vsa_enroll_after6_transfer F3.1 
  vsa_enroll_elsewhere_after6_transfer F3.1 
  counted_pct A8. 
CACHE. 
EXECUTE. 

SAVE OUTFILE='J:\public_html\IntroSPSS\collegeCompletion.sav'
  /COMPRESSED.


*Examining data with the list command.
LIST chronname state.

* create a new variable called filter1.
COMPUTE filter1=(grad_100_value=0 & level="4-year").
FILTER BY filter1.
* FILTER is used to exclude cases from program procedures without deleting them from the active dataset. 
* When FILTER is in effect, cases with a zero or missing value for the specified variable are not used in program procedures. 
* Those cases are not actually deleted and are available again if the filter is turned off. To see the current filter status, use the SHOW command.
LIST chronname state control.
USE all.

*Looking at means, standard deviations, min and max values, appropriate for interval variables.
DESCRIPTIVES VARIABLES=grad_100_value grad_150_value student_count fte_value med_sat_value 
    endow_value ft_fac_value.
**Endowments per student among 4-year public universities.
COMPUTE filter2=(control='Public' & level='4-year').
FILTER BY filter2.
DESCRIPTIVES VARIABLES=endow_value.
USE all.
**Which public universities have the biggest endowments/student?.
*Here I'll use the temporary command, instead (only available in syntax).
TEMPORARY.
SELECT IF (control='Public' & level='4-year' & endow_value>100000).
LIST chronname endow_value.
*The temporary command stays in effect only unil the next executable command is excecuted.
*Normally the select if command would delete data that evaluates to false, but preceded by temporary, it acts as a filter.

*Frequency distributions, appropriate for categorical/ordered variables.
FREQUENCIES VARIABLES=level control.
*Alternatively:
FREQ
   /VARIABLES= level control.

*Cross-tab, view the relationship between two categorical/ordered variables.
CROSSTABS
  /TABLES=control BY level
  /CELLS=COUNT COLUMN. 

*Graphs, Histograms: the distribution of one inteval variable.
GRAPH
  /HISTOGRAM=grad_150_value.

GRAPH
  /HISTOGRAM(NORMAL)=pell_value.

GRAPH
   /HISTOGRAM=student_count.
*Who's got 250k students?.
TEMPORARY.
SELECT IF (student_count>200000).
LIST chronname student_count.

*Graphs, Scatterplots: the relationship between two interval vaiables.
FILTER BY filter2.
*Filter2 uses only 4-year colleges under public control.
GRAPH
  /SCATTERPLOT=pell_value WITH grad_150_value.
GRAPH
  /SCATTERPLOT=med_sat_value WITH grad_150_value.
GRAPH
  /SCATTERPLOT=aid_value WITH grad_150_value.
USE all.

*Boxplots, compare the distribution of an interval variable across the categories of a categorical/ordered variable.
*Single variable.
EXAMINE VARIABLES=grad_150_value 
  /PLOT=BOXPLOT.
*Alternatively:
EXAMINE
   /VARIABLES=grad_150_value
   /PLOT=BOXPLOT.

*Variable grouped by categorical variable.
EXAMINE VARIABLES=grad_150_value BY control
  /PLOT=BOXPLOT
  /STATISTICS=NONE
  /NOTOTAL.
*SPSS warns: This procedure cannot use string characters longer than 8 bytes. The values will be truncated.
*So I'll redefine the control variable, recoding it to take on a number for each category instead..
AUTORECODE VARIABLES=control 
  /INTO controlcat
  /PRINT.
*Autorecode converts string variables to numeric variables.
*And try again.
EXAMINE VARIABLES=grad_150_value BY controlcat
  /PLOT=BOXPLOT
  /STATISTICS=NONE
  /NOTOTAL.

*Variable grouped by two categorical variables.
EXAMINE VARIABLES=grad_150_value BY controlcat BY level 
  /PLOT=BOXPLOT 
  /STATISTICS=NONE
  /NOTOTAL.

*Data manipulation, renaming.
RENAME VARIABLES (grad_150_value=grad150) (grad_100_value=grad100).

*Data manipulation, recoding.
RECODE grad100 grad150 (0 thru 32.9 = 1) (33.0 thru 66.0 = 2) (66.1 thru 100 = 3) INTO gradrate100 gradrate150.
FREQ VAR = gradrate100 gradrate150.

*Data manipulation, computing new variables.
*As mathematical function of exisitng variable.
COMPUTE lnaid = ln(aid_value).
DESCRIPTIVES VARIABLES = aid_value lnaid.

*As logical function of existing variables.
* create new variable called "research".
FREQ VAR=basic.
IF basic="Research Universities--high research activity" OR basic="Research Universities--very high research activity" OR basic="Doctoral and Research Universities" research=1.
RECODE research (MISSING=0).
FREQ VAR=research.

* create new variable called "flagshipdum".
IF flagship="X" flagshipdum=1.
RECODE flagshipdum (MISSING=0).
FREQ VAR=flagshipdum.

*Adding labels to variables.
VARIABLE LABELS grad100  "Percent of first-time, full-time undergrads completing degree on time".
VARIABLE LABELS research  "Carnegie Classification-Research".
FREQ VAR = research.

*Adding labels to values.
VALUE LABLES gradrate100 gradrate150 1 "Less than 33%" 2 "33-66%" 3 "More than 66%".
FREQ VAR = gradrate100 gradrate150.

*Save the work.
SAVE OUTFILE='C:\Users\jcf2d\Documents\workshops\SPSS\collegeCompletionIntroSPSS.sav'
  /COMPRESSED.


**Some analysis
/*Among 4-year research universities, do graduation rates vary by private/public control? *.
FILTER BY research.
CROSSTABS
  /TABLES=gradrate100 BY control
  /CELLS=COUNT COLUMN
  /STATISTICS=CHISQ. 
USE all.

COMPUTE research2=research.
DO IF control="Private for-profit".
RECODE research2 (1=0).
END IF.
FREQ VAR=research research2.

FILTER BY research2.
CROSSTABS
  /TABLES=gradrate100 BY control
  /CELLS=COUNT COLUMN
  /STATISTICS=CHISQ. 
USE all.

FILTER BY research.
ONEWAY grad150 BY controlcat
  /STATISTICS DESCRIPTIVES 
  /POSTHOC=BONFERRONI ALPHA(0.05).
USE all.

RECODE controlcat (1=1) (2 thru 3=0) INTO privateFP.
RECODE controlcat (1=0) (2=1) (3=0) INTO privateNFP.
RECODE controlcat (1 thru 2=0) (3=1) INTO public.
FREQ VAR=controlcat privateFP privateNFP public.

FILTER BY research.
REGRESSION
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /DEPENDENT grad150
  /METHOD=ENTER privateFP privateNFP.
USE all.

/*Among 4-year non-research colleges, do graduation rates vary by control (private/public, profit/non) */
IF level='4-year' AND research=0 nonresearch=1.
FILTER BY nonresearch.
CROSSTABS
  /TABLES=gradrate100 BY control
  /CELLS=COUNT COLUMN
  /STATISTICS=CHISQ. 

ONEWAY grad150 BY controlcat
  /STATISTICS DESCRIPTIVES 
  /POSTHOC=BONFERRONI ALPHA(0.05).

REGRESSION
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /DEPENDENT grad150
  /METHOD=ENTER privateFP privateNFP.
USE all.

* Among 4-year research universities, do graduation rates vary by average student aid?.
FILTER BY research.
GRAPH
  /SCATTERPLOT(BIVAR)=lnaid WITH grad150.

* Does the relationship look the same for public/private universities?.
GRAPH
  /SCATTERPLOT(BIVAR)=lnaid WITH grad150 BY controlcat
  /TITLE = "6-Year Completion Rates by Average Student Aid".



COMMENT BOOKMARK;LINE_NUM=8;ID=1.
